@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0913';
+our $VERSION = '0.0914';
 
 use v5.36;
 
@@ -141,7 +141,7 @@ sub single ($self, $device, $dt, $event) {
     my ($ev, $chan, $note, $val) = $event->@*;
     return 0 if defined $self->trigger && $note != $self->trigger;
 
-    my $value = $self->value || $val;
+    my $value = $self->value // $val;
     my $cc = [ 'control_change', $self->channel, $self->control, $value ];
     $self->rtc->send_it($cc);
 
@@ -376,7 +376,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0913
+version 0.0914
 
 =head1 SYNOPSIS
 
